searchData={"items":[{"type":"module","title":"GlobEx","doc":"Provides glob expressions for Elixir.\n\nA glob expression looks like an ordinary path, except that the following\n\"wildcard characters\" are interpreted in a special way:\n\n  * `?` - matches one character.\n  * `*` - matches any number of characters up to the end of the filename, the\n    next dot, or the next slash.\n  * `**` - two adjacent `*`'s used as a single pattern will match all\n    files and zero or more directories and subdirectories.\n  * `[char1,char2,...]` - matches any of the characters listed; two\n    characters separated by a hyphen will match a range of characters.\n    Do not add spaces before and after the comma as it would then match\n    paths containing the space character itself.\n  * `{item1,item2,...}` - matches one of the alternatives.\n    Do not add spaces before and after the comma as it would then match\n    paths containing the space character itself.\n\nOther characters represent themselves. Only paths that have\nexactly the same character in the same position will match. Note\nthat matching is case-sensitive: `\"a\"` will not match `\"A\"`.\n\nDirectory separators must always be written as `/`, even on Windows.\nYou may call `Path.expand/1` to normalize the path before invoking\nthis function.\n\nA character preceded by  loses its special meaning.\nNote that  must be written as \\ in a string literal.\nFor example, \"\\?*\" will match any filename starting with ?.\n\nGlob expressions in can be created using `compile/2`, `compile!/2` or the\nsigils ~g (see `GlobEx.Sigils.sigil_g/2`) or ~G (see\n`GlobEx.Sigils.sigil_G/2`).\n\n```elixir\n# A simple glob expressions matching all `.exs` files in a tree. By default,\n# the patterns `*` and `?` do not match files starting with a `.`.\n~g|**/*.exs|\n\n# The modifier `d` let the glob treat files starting with a `.` as any other\n# file.\n~g|**/*.exs|d\n```","ref":"GlobEx.html"},{"type":"function","title":"GlobEx.compile/2","doc":"Compiles the glob expression.\n\nIt returns `{:ok, regex}` in case of success, `{:error, reason}` otherwise.\n\nSee the module documentation for how to write a glob expression.\n\nBy default, the patterns `*` and `?` do not match files starting with a `.`.\nThis behaviour can be change with the option `:match_dot`.","ref":"GlobEx.html#compile/2"},{"type":"function","title":"Options - GlobEx.compile/2","doc":"* `:match_dot` - (boolean) if `false`, the special wildcard characters `*` and `?`\n    will not match files starting with a `.`. If `true`, files starting with\n    a `.` will not be treated specially. Defaults to `false`.","ref":"GlobEx.html#compile/2-options"},{"type":"function","title":"Examples - GlobEx.compile/2","doc":"iex> GlobEx.compile(\"src/**/?oo.ex\")\n    {:ok, ~g|src/**/?oo.ex|}\n\n    iex> GlobEx.compile(\"src/{a,b/?oo.ex\")\n    {:error, %GlobEx.CompileError{reason: {:missing_delimiter, 5}}}","ref":"GlobEx.html#compile/2-examples"},{"type":"function","title":"GlobEx.compile!/2","doc":"Compiles the glob expression and raises GlobEx.CompileError in case of errors.\n\nSee the module documentation for how to write a glob expression and\n`compile/2` for the available options.","ref":"GlobEx.html#compile!/2"},{"type":"function","title":"GlobEx.ls/1","doc":"Traverses paths according to the given `glob` expression and returns a list of\nmatches.\n\nSee the module documentation for how to write a glob expression.","ref":"GlobEx.html#ls/1"},{"type":"function","title":"Examples - GlobEx.ls/1","doc":"iex> GlobEx.ls(~g|{lib,test}/**/*.{ex,exs}|)\n    [\n      \"lib/glob_ex.ex\",\n      \"lib/glob_ex/compiler.ex\",\n      \"lib/glob_ex/compiler_error.ex\",\n      \"lib/glob_ex/sigils.ex\",\n      \"test/glob_ex/compiler_test.exs\",\n      \"test/glob_ex_test.exs\",\n      \"test/test_helper.exs\"\n    ]","ref":"GlobEx.html#ls/1-examples"},{"type":"function","title":"GlobEx.match?/2","doc":"Returns a boolean indicating whether there was a match or not.\n\nSee the module documentation for how to write a glob expression.","ref":"GlobEx.html#match?/2"},{"type":"function","title":"Examples - GlobEx.match?/2","doc":"iex> GlobEx.match?(~g|{lib,test}/**/*.{ex,exs}|, \"lib/foo/bar.ex\")\n    true\n\n    iex> GlobEx.match?(~g|{lib,test}/**/*.{ex,exs}|, \"lib/foo/bar.java\")\n    false","ref":"GlobEx.html#match?/2-examples"},{"type":"type","title":"GlobEx.t/0","doc":"","ref":"GlobEx.html#t:t/0"},{"type":"module","title":"GlobEx.Sigils","doc":"This module provides the sigils `~g||` and `~G||`.","ref":"GlobEx.Sigils.html"},{"type":"macro","title":"GlobEx.Sigils.sigil_G/2","doc":"Handles the sigil `~G` for globs.\n\nIt returns a glob expression pattern without interpolations and without escape\ncharacters.\n\nSee the module documentation `GlobEx` for how to write a glob expression.","ref":"GlobEx.Sigils.html#sigil_G/2"},{"type":"macro","title":"Examples - GlobEx.Sigils.sigil_G/2","doc":"iex> ~G|*.txt|\n    ~g|*.txt|\n\n    iex> GlobEx.match?(~G|f#{a,b}|, \"f#a\")\n    true","ref":"GlobEx.Sigils.html#sigil_G/2-examples"},{"type":"macro","title":"GlobEx.Sigils.sigil_g/2","doc":"Handles the sigil `~g` for globs.\n\nSee the module documentation `GlobEx` for how to write a glob expression.","ref":"GlobEx.Sigils.html#sigil_g/2"},{"type":"macro","title":"Examples - GlobEx.Sigils.sigil_g/2","doc":"iex> ~g|*.txt|\n    ~g|*.txt|\n\n    iex> ~g|*.#{\"txt\"}|\n    ~g|*.txt|\n\n    iex> GlobEx.match?(~g|f\\#{a,b}|, \"f#a\")\n    true","ref":"GlobEx.Sigils.html#sigil_g/2-examples"},{"type":"exception","title":"GlobEx.CompileError","doc":"An exception raised when the compilation of a glob expression fails.","ref":"GlobEx.CompileError.html"},{"type":"type","title":"GlobEx.CompileError.reason/0","doc":"","ref":"GlobEx.CompileError.html#t:reason/0"},{"type":"type","title":"GlobEx.CompileError.t/0","doc":"","ref":"GlobEx.CompileError.html#t:t/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}